@@ -1,6 +1,7 @@
 from .preprocess import cat, get, regen, name, constant, Classification, TokenClassification, MultipleChoice
 from .metadata import bigbench_discriminative_english, blimp_hard, imppres_presupposition, imppres_implicature, udep_en_configs, udep_en_labels
 from datasets import get_dataset_config_names, Sequence, ClassLabel, Dataset, DatasetDict
+
 # variable name: dataset___config__task
 
 ###################### NLI/paraphrase ###############################
@@ -393,7 +394,25 @@ ethos___multilabel = Classification(
     splits=["train", None, None]
 )
 
-tweet_eval = Classification(sentence1="text", labels="label", config_name=["emoji", "emotion", "hate", "irony", "offensive", "sentiment", "stance_abortion", "stance_atheism", "stance_climate", "stance_feminist", "stance_hillary"])
+tweet_eval = Classification(sentence1="text", labels="label",
+    config_name=["emoji", "emotion", "hate", "irony", "offensive", "sentiment"])
+
+def stance_kwargs(topic):
+    return {
+        "sentence1": constant(f'Topic: {topic}. \n Opinion:\n'), 
+        "sentence2": "text", 
+        "labels": "label", 
+        "config_name": f"stance_{topic.lower()}",
+        "dataset_name": "tweet_eval"
+    }
+
+tweet_eval_abortion = Classification(**stance_kwargs("abortion"))
+tweet_eval_atheism  = Classification(**stance_kwargs("atheism"))
+tweet_eval_climate  = Classification(**stance_kwargs("climate"))
+tweet_eval_feminist = Classification(**stance_kwargs("feminist"))
+tweet_eval_hillary  = Classification(**stance_kwargs("Hillary"))
+
+    
 
 discovery = Classification("sentence1", "sentence2", labels="label", config_name=["discovery"])
 
@@ -488,7 +507,7 @@ go_emotions___simplified = Classification(sentence1="text", labels="labels")
 #ecthr_cases___violation_prediction = Classification(labels="labels", dataset_name="ecthr_cases", config_name="violation-prediction")
 #   too long
 
-scicite = Classification(sentence1="string", labels="label")
+scicite = Classification(sentence1="string", labels="label",dataset_name="allenai/scicite")
 
 liar = Classification(sentence1="statement", labels="label")
 
@@ -556,7 +575,7 @@ SpeedOfMagic_ontonotes_english = TokenClassification(tokens="tokens", labels="ne
 
 blog_authorship_corpus__gender    = Classification(sentence1="text",labels="gender")
 blog_authorship_corpus__age       = Classification(sentence1="text",labels="age")
-blog_authorship_corpus__horoscope = Classification(sentence1="text",labels="horoscope")
+#blog_authorship_corpus__horoscope = Classification(sentence1="text",labels="horoscope")
 blog_authorship_corpus__job       = Classification(sentence1="text",labels="job")
 
 launch_open_question_type = Classification(sentence1="question", labels="resolve_type", dataset_name="launch/open_question_type")
@@ -595,7 +614,9 @@ circa = Classification(
 #    constant(""), choices=["buggy","fixed"], labels=constant(0),
 #    config_name="medium")
 
-effective_feedback_student_writing = Classification("discourse_text", labels="discourse_effectiveness",dataset_name="YaHi/EffectiveFeedbackStudentWriting")
+#effective_feedback_student_writing = Classification("discourse_text", 
+#labels="discourse_effectiveness",dataset_name="YaHi/EffectiveFeedbackStudentWriting")
+# discontinued /!\
 
 #promptSentiment = Classification("text",labels="label",dataset_name="Ericwang/promptSentiment")
 #promptNLI = Classification("premise","hypothesis",labels="label",dataset_name="Ericwang/promptNLI")
@@ -933,7 +954,7 @@ starcon = Classification('argument','topic','label',dataset_name="tasksource/sta
 
 banking77 = Classification("text",labels="label",dataset_name="PolyAI/banking77")
 
-ruletaker = Classification("context","text","label",dataset_name="tasksource/ruletaker")
+ruletaker = Classification("context","question","label",dataset_name="tasksource/ruletaker")
 
 lsat_qa = MultipleChoice(
     cat(['passage','question']),
@@ -979,9 +1000,124 @@ subjectivity = Classification("Sentence",labels="Label",dataset_name="tasksource
 
 moh   = Classification("context","expression","label", dataset_name="tasksource/MOH")
 vuac  = Classification("context","expression","label", dataset_name="tasksource/VUAC")
-trofi = Classification("context","expression","label", dataset_name="tasksource/TroFi")
+trofi = Classification("context","expression","label", dataset_name="tasksource/TroFi", splits=['train',None,'test'])
 
-sharc_classification = Classification("snippet", cat(["scenario","question"]),labels="answer",dataset_name='sharc_modified',config_name='mod',
-    pre_process = lambda ds:ds.filter(lambda x:x['answer'] in {"Yes","No","Irrelevant"}))
+sharc_classification = Classification("snippet", lambda x:f'{x["scenario"]}\n{x["question"]}',
+    labels=lambda x:x["answer"] if x['answer'] in  {"Yes","No","Irrelevant"} else "Clarification needed",
+    dataset_name='sharc_modified',config_name='mod')
 
-conceptrules_v2 = Classification("context", "text", "label", dataset_name="tasksource/conceptrules_v2")
\ No newline at end of file
+conceptrules_v2 = Classification("context", "text", "label", dataset_name="tasksource/conceptrules_v2")
+
+scidtb = Classification("unit1_txt","unit2_txt","label", dataset_name="metaeval/disrpt",config_name='eng.dep.scidtb.rels')
+
+chunking = TokenClassification("tokens","chunk_tags", dataset_name="conll2000")
+
+few_nerd = TokenClassification("tokens","fine_ner_tags",dataset_name="DFKI-SLT/few-nerd",config_name='supervised')
+finer = TokenClassification('tokens','ner_tags',dataset_name='nlpaueb/finer-139')
+
+label_nli = Classification("premise","hypothesis","labels",dataset_name='tasksource/zero-shot-label-nli')
+
+com2sense = Classification("sent",labels="label",dataset_name="tasksource/com2sense",splits=['train',"validation",None])
+
+scone = Classification('sentence1_edited','sentence2_edited','gold_label_edited',dataset_name="tasksource/scone")
+
+winodict = MultipleChoice(cat(['definition','sentence']),['option1','option2'],'label',dataset_name='tasksource/winodict')
+
+fool_me_twice = Classification(
+    lambda x: " ".join(a['text'] for a in x['gold_evidence']),
+    'text', 'label', dataset_name='tasksource/fool-me-twice')
+
+monli = Classification("sentence1","sentence2","gold_label", dataset_name="tasksource/monli")
+
+causality = Classification('premise','hypothesis','relation', dataset_name='tasksource/corr2cause')
+
+lsat = MultipleChoice(cat(['passage','question']), choices_list='references',labels='gold_index',dataset_name='lighteval/lsat_qa',config_name='all')
+
+apt = Classification('text_a','text_b',name('labels',['not_paraphrase','paraphrase']),dataset_name='tasksource/apt')
+
+#xsum_factuality = Classification("summary",labels="is_factual")
+
+financial_sentiment = Classification("text",labels=name('label',['Bearish','Bullish','Neutral']),
+    dataset_name="zeroshot/twitter-financial-news-sentiment")
+
+def _icl_rand(x):
+    import random
+    return random.Random(x['sentence1'][:50]).randint(0,1) #deterministic label for each input
+
+icl = Classification("inputs", lambda x: x['symbols'][_icl_rand(x)],
+    labels=lambda x: int(x['symbols'][_icl_rand(x)]==x['targets']),
+    dataset_name="tasksource/icl-symbol-tuning-instruct",
+    pre_process=lambda ds:ds.filter(lambda x:len(x['inputs'])<200*4), # 200 tokens of 4 char 
+    post_process=lambda ds:ds.cast_column('labels',ClassLabel(names=['False','True']))
+)
+
+space_nli = Classification("premises","hypothesis","label",dataset_name="tasksource/SpaceNLI")
+
+propsegment = Classification("hypothesis","premise",
+    labels = lambda x:{'n':'neutral','e':'entailment','c':'contradiction'}[x['label']],
+    dataset_name="sihaochen/propsegment",config_name='nli')
+
+hatemoji = Classification('text',labels=name("label_gold", ['not-hate-speech','hate-speech']),
+    dataset_name="HannahRoseKirk/HatemojiBuild")
+
+regset = Classification("context",labels="answer",dataset_name='tasksource/regset')
+
+esci = Classification('query','product_text','esci_label',
+    dataset_name="tasksource/esci",
+    pre_process=lambda ds:ds.filter(lambda x:x['product_locale']=='us'))
+
+def _preprocess_chatbot_arena(ds):
+    ds=ds.filter(lambda x:x['winner'] in ["model_a","model_b"])
+    ds=ds.filter(lambda x:x['language']=="English")
+
+    def _unroll(x):
+        f=lambda x:"\n".join([f"{turn['role']}:\n{turn['content']}" for turn in x])
+        x['conversation_a'] = f(x['conversation_a'])
+        x['conversation_b'] = f(x['conversation_b'])
+        return x
+    ds=ds.map(_unroll)
+    return ds
+
+chatbot_arena = MultipleChoice(constant(""),
+    choices=["conversation_a","conversation_b"],
+    labels=lambda x: ["model_a","model_b"].index(x["winner"]),
+    dataset_name="lmsys/chatbot_arena_conversations",
+    pre_process=_preprocess_chatbot_arena)
+
+dnd_intent = Classification("examples",labels="label_names",
+    dataset_name='neurae/dnd_style_intents')
+
+fld = Classification("context","hypothesis", "proof_label",
+    dataset_name="hitachi-nlp/FLD.v2")
+
+sdoh_nli = Classification("premise","hypothesis",labels=lambda x:{True:"entailment",False:"not-entailment"}[x['label']],
+    dataset_name="tasksource/SDOH-NLI")
+
+scifact_entailment = Classification(lambda x:"\n".join(x["abstract"]),"claim",
+    labels=lambda x:x['verdict'].replace('NEI','NEUTRAL').lower(),
+    dataset_name="allenai/scifact_entailment")
+
+feasibilityQA = Classification(cat(['knowledge','premise']),'hypothesis','binary_classification_label',
+    dataset_name="tasksource/feasibilityQA")
+                               
+simple_pair = Classification("premise","hypothesis","label", dataset_name="tasksource/simple_pair")
+adjective_scale_probe = Classification("premise","hypothesis","label", dataset_name="tasksource/AdjectiveScaleProbe-nli")
+repectively_nli = Classification("premise","hypothesis","label",dataset_name="tasksource/resnli")
+
+spartun=MultipleChoice(cat(["story","question"]),choices_list="candidate_answers",
+    labels=lambda x: [c.lower() for c in x['choices_list']].index(x["answer"][0].lower()),
+    pre_process=lambda ds:ds.filter(lambda x:len(x['answer'])==1),
+    dataset_name="tasksource/SpaRTUN")
+
+resq=MultipleChoice(cat(["story","question"]),choices_list="candidate_answers",
+    labels=lambda x: [c.lower() for c in x['choices_list']].index(x["answer"][0].lower()),
+    pre_process=lambda ds:ds.filter(lambda x:len(x['answer'])==1),
+    dataset_name="tasksource/ReSQ")
+
+semantic_fragments_nli = Classification("sentence1","sentence2","gold_label",
+    dataset_name="tasksource/semantic_fragments_nli")
+
+moritz_zs_nli = Classification('text','hypothesis','labels',
+    pre_process=lambda ds:ds.filter(lambda x:x['task_name'] not in  ["mnli", "anli", "fevernli", "wanli", "lingnli"]),
+    dataset_name="MoritzLaurer/dataset_train_nli"
+) 
\ No newline at end of file
